Boutique POS - Home

JD
Jane Doe
Cashier

# Products

All Items
Tops
Dresses
Bottoms
Outerwear
Accessories
👗 12
Summer Floral Dress
S / M / L • Blue
$89.00
👚 3
Silk Blouse
XS / S / M • Ivory
$65.00
👖 18
High-Rise Jeans
24-32 • Indigo
$78.00
🧥 7
Linen Blazer
S / M / L • Tan
$145.00
👜 2
Leather Tote
One Size • Black
$195.00
🧣 24
Cashmere Scarf
One Size • Camel
$85.00
👠 9
Strappy Heels
35-41 • Nude
$128.00
🎀 31
Hair Ribbon Set
Pack of 3 • Multi
$22.00
Current Sale 3
Clear All
👗
Summer Floral Dress
Size M • Blue
1
$89.00
👚
Silk Blouse
Size S • Ivory
2
$130.00
🧣
Cashmere Scarf
One Size • Camel
1
$85.00